| Package name                                                  | Package hash                                                  |
| ------------------------------------------------------------- | ------------------------------------------------------------- |
| protocol/fetchai/gym/1.0.0                                    | `bafybeidepuani7dw6r2wwmtxfeefqwhnctprmwatzqbxg2achstc6kpfke` |
| connection/fetchai/gym/0.19.0                                 | `bafybeiguq4eduf35lvs3ltmi3jabpokz6raadrje3c274f5dnvfipdl7jm` |
| protocol/fetchai/default/1.0.0                                | `bafybeibtqp56jkijwjsohk4z5vqp6pfkiexmnmk5uleteotbsgrypy6gxm` |
| protocol/valory/acn/1.1.0                                     | `bafybeic2pxzfc3voxl2ejhcqyf2ehm4wm5gxvgx7bliloiqi2uppmq6weu` |
| protocol/valory/contract_api/1.0.0                            | `bafybeialhbjvwiwcnqq3ysxcyemobcbie7xza66gaofcvla5njezkvhcka` |
| protocol/valory/http/1.0.0                                    | `bafybeiejoqgv7finfxo3rcvvovrlj5ccrbgxodjq43uo26ylpowsa3llfe` |
| protocol/valory/ledger_api/1.0.0                              | `bafybeige5agrztgzfevyglf7mb4o7pzfttmq4f6zi765y4g2zvftbyowru` |
| connection/fetchai/http_server/0.22.0                         | `bafybeihvscddpxjbtqsetngmxo3kiht2wqhosmwiyuh3f6zjti3x3byu5u` |
| connection/fetchai/stub/0.21.0                                | `bafybeictgpdqbpyppmoxn2g7jkaxvulihew7zaszv4xyhgvsntq7tqs7wi` |
| connection/valory/ledger/0.19.0                               | `bafybeigo5vst3zlltkouenwxuzn6c47yr2fbbml6dl2o32rfnsezmalgnu` |
| connection/valory/p2p_libp2p/0.1.0                            | `bafybeiaykya7tvir7k5scovjzuagpfcftvptxoi2od5qqqvukwglsrrtzy` |
| connection/valory/p2p_libp2p_client/0.1.0                     | `bafybeihge56dn3xep2dzomu7rtvbgo4uc2qqh7ljl3fubqdi2lq44gs5lq` |
| connection/valory/p2p_libp2p_mailbox/0.1.0                    | `bafybeieufv6tbei3vza7bg7ggzsvyvwmzps5kghxlar3drhme6d7mxawvy` |
| contract/fetchai/erc1155/0.22.0                               | `bafybeiff7a6xncyad53o2r7lekpnhexcspze6ocy55xtpzqeuacnlpunm4` |
| protocol/fetchai/fipa/1.0.0                                   | `bafybeid6o7dxutkendclxxtxo3pyizrfho3vxyj5j5sowkysmuqamywb24` |
| protocol/fetchai/oef_search/1.0.0                             | `bafybeicysyqgag7gsbpvly5mzhlwwiosl7gupgmohx233gynw7xtgsxewy` |
| protocol/fetchai/state_update/1.0.0                           | `bafybeiefezh5ei6gntomi6g5iq4raabktari3wc6t4g6jf23bgo7cgwlcq` |
| protocol/open_aea/signing/1.0.0                               | `bafybeie7xyems76v5b4wc2lmaidcujizpxfzjnnwdeokmhje53g7ym25ii` |
| skill/fetchai/echo/0.19.0                                     | `bafybeibtjwgshqkgn5og7izogitnc66ug7pfhikcxlf2y46ixknpoxeyee` |
| skill/fetchai/error_test_skill/0.1.0                          | `bafybeihsbtlpe7h6fsvoxban5rilkmwviwkokul5cqym6atoolirontiyu` |
| skill/fetchai/gym/0.20.0                                      | `bafybeifaccpsmby27az6geu4d6m7xcjk2hop7ihtleqeeasphnhn2dp234` |
| skill/fetchai/http_echo/0.20.0                                | `bafybeieysvwshmy2rlfzqclcfhl263roy6z3skvmy3ikmfcoioxhnhp67i` |
| agent/fetchai/error_test/0.1.0                                | `bafybeif6q4pyu4vvtaljm33rw2fft3f5fu33byhku3qkspy4vhgzczqhwy` |
| agent/fetchai/gym_aea/0.25.0                                  | `bafybeif5c657r3ixuosbyihtsdzr2tqifikxgy5e6t7ur2jmhtiolina3m` |
| agent/fetchai/my_first_aea/0.27.0                             | `bafybeicrgya4gln4lqr3ba76t2cuyik37lcgr64kzna2fkoseseobytaa4` |
| agent/open_aea/gym_aea/0.1.0                                  | `bafybeibyyl4wtnrfxeoed3kjnlftphkcikdqrgf76u34v4wbvwgsqfqrgy` |
| agent/open_aea/http_echo/0.1.0                                | `bafybeie6dxx5zbu6bz7at7kqj3thjvvzucj45f3tksbio5dg23ywsbb2ty` |
| agent/open_aea/my_first_aea/0.1.0                             | `bafybeibv7nlyxldyj5ntivsu74ylul4dltpfvkfa46k2pbveetfpkvz4jm` |
| connection/fetchai/local/0.20.0                               | `bafybeigukufpgy2sdkv5qqde47dhigbjitxcrxwg6sl6unlpbc7wbxqyhm` |
| connection/valory/http_client/0.23.0                          | `bafybeifgeqgryx6b3s6eseyzyezygmeitcpt3tkor2eiycozoi6clgdrny` |
| connection/valory/test_libp2p/0.1.0                           | `bafybeih4vz7pprbjhe5g4tnf52ttkooii66woxbhifjc7wk5xdt6b6asiu` |
| protocol/fetchai/tac/1.0.0                                    | `bafybeiaukfwe7wbpikztprlmrfpphsxqpdzgamkbhvqyz54tl3k73kzsvi` |
| skill/fetchai/erc1155_client/0.28.0                           | `bafybeibffkywiuz5gwm6yn4v2fhkz35i77zl5ya4tzq4wksvga2mvkeojm` |
| skill/fetchai/erc1155_deploy/0.30.0                           | `bafybeif6dmam4pvsdesvgb6n3ga4uf7dxikaynbqomxpswmhqlvcuz7vti` |
| skill/fetchai/error/0.17.0                                    | `bafybeignei6feootyjzrqdt5j5yx7r4nrzuy6tdgdgsmrncldt5bud2dri` |
| skill/fetchai/fipa_dummy_buyer/0.2.0                          | `bafybeid7rzqruvc3fkesueig2mbzy2qsfplieircyjzwbdl7c6q5eauiky` |
| skill/fetchai/generic_buyer/0.26.0                            | `bafybeiebwhfzs7vbdrnm7cqu5dc4r3wqdaeirmps5pfwexjd3ms5ss7xk4` |
| skill/fetchai/generic_seller/0.27.0                           | `bafybeiapnkdtn3qrh36cxpbhalv2yaunnauieo7sxori46a7ohsp7xuzlq` |
| skill/fetchai/task_test_skill/0.1.0                           | `bafybeidv77u2xl52mnxakwvh7fuh46aiwfpteyof4eaptfd4agoi6cdble` |
